AutocompleteResult class

Constructors

AutocompleteResult({ELocation? eLocation, SuggestedSearch? suggestedSearch, bool? isRequestForCurrentLocation})

Properties

eLocation → ELocation?
final
hashCode → int
The hash code for this object.
no setterinherited
isRequestForCurrentLocation → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suggestedSearch → SuggestedSearch?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic> map) → AutocompleteResult